#ifndef __TPM_SECURITY_H__
#define __TPM_SECURITY_H__

#include <err.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <stdint.h>
#include <stdbool.h>

struct TPMAlgorithm {
	char alg[16];
};

struct TPMSupportAlgorithm {
	uint32_t count;
	struct TPMAlgorithm  algs[128];
};

struct TPMTrustedRootData {
	char chipType[8];
	char chipVersion[8];
	char specVersion[8];
	char manufacturer[4];
	char chipname[128];
	uint32_t nvDefined;
	char supportAlg[1024]; 
};


struct TPMBootMeasureData{
	char time[64];    //度量时间
	char pname[256]; //度量进程名
	char measure_result[10];
	int start_measure_error_number;    
};

struct TPMBootMeasureLog {
	uint32_t numbers;
	struct TPMBootMeasureData report[32];
} ;

struct TPM_TrustChainData {
	char bios[16];
	char grub[16];
	char kernel[16];
	char time[64];
	int  totalnum;
	int  failnum;
};


typedef enum 
{
	tpm_tpcm = 0,
	tpm_uefi = 1,
	tpm_grub = 2,
	tpm_bios = 3
}TpmReportOpt;

#ifdef __cplusplus
extern "C" {
#endif


	int TPM_GetTrustedRootData(struct TPMTrustedRootData *data, int nvpasswd_len, char * nvpasswd);
	int TPM_GetBootMeasureStatus();
	int TPM_GetBootMeasureCfgStatus();
	int TPM_SetBootMeasureCfgStatus(int status, char *devicepath, int *trustrootmode, int nvpasswd_len, char * nvpasswd, int authorization_len, char * authorization_para);
	int TPM_SetReCollectMeasureStandarValue(char *filepath, int nvpasswd_len, char * nvpasswd, int authorization_len, char * authorization_para);
	int TPM_GetReCollectMeasureStandarValue();
	int TPM_GetBootMeasureData(int reportopt, struct TPMBootMeasureData **list, int *count);
	int TPM_GetHistoryBootMeasureLog(struct TPMBootMeasureLog **list, int *count);

	int TPM_GetBootMode();
	int TPM_SetBootMode(int status);
	int TPM_SaveFlashBootMeasureLog(); 
	int TPM_AddFile(char *filepath, int nvpasswd_len, char * nvpasswd, int authorization_len, char * authorization_para);
	int TPM_DealFile(char *filepath, int nvpasswd_len, char * nvpasswd, int authorization_len, char * authorization_para);
	int TPM_GetTrustChainData(struct TPM_TrustChainData* data);




#ifdef __cplusplus
}
#endif


#endif //__TPM_SECURITY_H__
